#!/bin/sh
###############################################################################
#
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#  File Information: %W%
#  Revision: %I%
#  Date: %G% %U%
#
###############################################################################

###############################################################################
# Set the program Non configurable variables required in all files using 
###############################################################################
gen_file_and_path=`echo $0 | sed 's/\\\\/\//g' `  # tweak the path for NT
PROGNAME=`basename "$gen_file_and_path"`
CONFIGFILE="<none>";
CURRENT_DATE=`date +"%b %d %Y %T"`;

###############################################################################
# Display Header Info
###############################################################################
display_header()
{

echo "";
echo "    ========================================================";
echo "    IBM Tivoli Monitoring - Tivoli Enterprise Data Warehouse";
echo "               Configuration and Status Snapshot            ";
echo "                        (c) IBM - Tivoli                    ";
echo "    ========================================================";
echo "";

return 0
}

###############################################################################
# Display Footer Info
###############################################################################
display_footer()
{
echo "";
echo "    ========================================================";
echo "    ================== Analysis Completed ==================";
echo "    ========================================================";
echo "";

return 0
}

###############################################################################
# Display Help
###############################################################################
display_help()
{
echo ""
echo "  Program:  $PROGNAME"
echo ""
echo "  Desc:     this script provides a snapshot of the ITM Managed Node"
echo "            configuration and Data Collector status. Run it on each"
echo "            Managed Node where the Warehouse Component is installed,"
echo "            after setting the Tivoli environment."
echo ""
echo "  Usage:    $PROGNAME [ options... ]"
echo ""
echo "  Options:"
echo "            -h, --help       = Help Inforamtion"
echo "            -d, --debug      = Run with Debug turned on"
echo "            -r  --retcode    = Display return code messages"
echo ""
echo "  Default Config File:"
echo "            $CONFIGFILE"
echo ""
echo "  Message Levels:"
echo "            (?) - User Input Required"
echo "            (I) - Informational"
echo "            (W) - Warning"
echo "            (F) - Fatal"
echo ""

return 0
}

###############################################################################
# Return codes and messages displayed by the program
# To call:	display_return_code_messages;
###############################################################################

display_return_code_messages()
{

echo "    ========================================================"
echo "    ================= Return Code Messages ================="
echo "    ========================================================"
echo ""
echo "       1 =  Invalid Authorization."
echo "       2 =  Cannot Determine a Valid Environment."
echo "       3 =  No RIM Object Defined on the Managed Node."
echo "       4 =  Cannot find the selected RIM Object."
echo "       5 =  Unable to Open a Valid RIM Session."
echo "       6 =  The RIM Object is not Properly Configured."
echo "       7 =  Unknown option."
echo ""

return 0;
}

###############################################################################
# Set the Debug Mode
###############################################################################
set_debug_mode()
{
echo "==> Setting Debug Mode..."

if [ -n "$DEBUG" ]; then
   set -x
   echo "      (I) Debug Mode Enabled"
else
   echo "      (I) Debug Disabled"
fi

return 0;
}

###############################################################################
# Pulls in the help messages shared routines
###############################################################################
include_helproutines()
{
echo "==> Including Help Messages Routines..."
. ./lib/helproutines.sh

echo "      (I) Done Including Help Messages Routines"
return 0;
}

###############################################################################
###############################################################################
########################## Main - Script Entry Point ##########################
###############################################################################
###############################################################################

#------------------
##### Parse the CLI
#------------------
while [ $# -ne 0 ]; do
  # Now look for the command line option
  case $1 in
    # Help Info
    --help|--HELP|-Help|-help|-H|-h)
        display_help;
        exit 0
        ;;
    # Run in Debug
    --debug|--DEBUG|--Debug|-debug|-D|-d)
        DEBUG=defined
        set_debug_mode;
        shift
        continue
        ;;
    # Display the return code messages
    --retcode|--RETCODE|--Retcode|-R|-r)
        display_header;
        display_return_code_messages;
        exit 0
        ;;
    # Default
    *)
        echo "      (F) ITM0007E Error. Unknown option ($1)"
        echo ""
        display_help;
        exit 7
        ;;
  esac
done

#------------------------------------
##### Display application header info
#------------------------------------
display_header;

echo "==> Analysis started at: $CURRENT_DATE"

#--------------------------------------------
##### Set the debug mode according to the CLI
#--------------------------------------------
set_debug_mode;

#---------------------------------------
##### Include the help messages routines
#---------------------------------------
include_helproutines;

#---------------------------------------------------------
##### Validate the identity of the user running the script
#---------------------------------------------------------

echo "==> Looking up TME 10 System Information..."

BO=`objcall 0.0.0 self 2>/dev/null`

if [ "$BO" = "" ]; then
  echo "      (F) ITM0001E Error. Invalid Authorization."
  itm_error_hint 1;
  echo "";
  exit 1;
else 
  echo "      (I) Valid User Found" 
fi

#------------------------------------
##### Get Environmental Configuration
#------------------------------------

echo "==> Getting Environmental Configuration..."

rc=0
OSERV=`objcall $BO getattr oserv 2>/dev/null`
rc=$?
EXECDIR=`objcall $OSERV query install_dir 2>/dev/null`
rc=$?
INTERP=`objcall $OSERV query interp 2>/dev/null`
rc=$?

if [ $rc -ne 0 ]; then
  echo "      (F) ITM0002E Error. Cannot Determine a Valid Environment."
  itm_error_hint 2;  
  exit 2
else
  echo "      (I) Environment Successfully Imported" 
fi

EXECDIR=`echo $EXECDIR | sed 's/\\\\/\//g'`   # tweak the path for NT

#-------------------------------
##### Enumerates the RIM Objects
#-------------------------------

echo "==> Looking for RIM Objects definition..."

RIMOIDS=`wlookup -ar RIM 2>/dev/null`;

if [ -z "$RIMOIDS" ]; then
  echo "      (F) ITM0003E Error. No RIM Object Defined on the Managed Node."
  itm_error_hint 3;
  echo "";
  exit 3;
else
  echo "      (I) Discovered the following RIM Objects:"
  echo "$RIMOIDS" | (
    i=1
    while read a b
    do
      echo "          $i) $a"
      i=`expr $i + 1`
    done
  )

  echo -n "      (?) Select the One used by Warehouse Component: "
  read answer
  export answer

  # TODO: add a check for the selected options...

  #-- pick up a RIM Object from the list
  RIMONM="default"
  RIMONM=`echo "$RIMOIDS" | (
    i=1
    while read a b
    do
    if [ "-$answer-" = "-$i-" ]; then
      echo $a;
      break;
    fi
    i=\`expr $i + 1\`;
    done
  )`

  echo "      (I) Using RIM Object ($RIMONM)";
  
fi

#--------------------------------------------------
##### Get the definition of the selected RIM Object
#--------------------------------------------------

echo "==> Retrieving RIM Object Information...";

QUERY_RIM_TYPE=0
QUERY_RIM_INFO=0

RIMOID=`wlookup -r RIM "$RIMONM" 2>/dev/null`

if [ -z "$RIMOID" ]; then

  echo "      (F) ITM0004E Error. Cannot Find the Selected RIM Object."
  itm_error_hint 4;
  echo "";
  exit 4;
  
else

  #-- Try to determine the vendor from the selected RIM Object
  RIM_TYPE=`idlcall $RIMOID get_type_name`
  
  if [ -z "$RIM_TYPE" ]; then
    echo "      (W) Warning. Cannot Determine the RIM Object Type."
    QUERY_RIM_TYPE=1
  elif [ -n "`echo $RIM_TYPE | grep EXCEPTION`" ]; then
    echo "      (W) Warning. An Exception Occurred while Reading the RIM Object Type."
    QUERY_RIM_TYPE=1
  else
    RIM_TYPE=`echo $RIM_TYPE | sed -e 's/\"//g'`
    echo "      (I) Valid RIM Object Type Found" 
    QUERY_RIM_TYPE=0
  fi

  #-- Ask user for vendor name if unable to get from the RIM Object
  if [ "$QUERY_RIM_TYPE" -eq 1 ]; then
    echo "      (?) Please Enter Your RDBMS Vendor Name" 
    echo -n "          [Sybase|Oracle|DB2|MS_SQL|Informix]: "
    read RIM_TYPE
  fi
  
  #-- Retrieve the RIM Object Configuration
  RIMINFO=`idlcall $RIMOID _get_rim_info`

  if [ -z "$RIMINFO" ]; then
    #-- signal the problem, but go ahead because we are really interested 
    #-- in a working RIM Object...
    echo "      (W) Warning. Cannot Retrieve the RIM Object Configuration."
    QUERY_RIM_INFO=1
  else
    #-- get the configuration info
    DBID=`idlarg 3 $RIMINFO`
    DBID=`echo $DBID | sed -e 's/\"//g'`
    DBUSER=`idlarg 4 $RIMINFO`
    DBUSER=`echo $DBUSER | sed -e 's/\"//g'`
    DBHOME=`idlarg 6 $RIMINFO`
    DBHOME=`echo $DBHOME | sed -e 's/\"//g'`
    DBSERVER=`idlarg 7 $RIMINFO`
    DBSERVER=`echo $DBSERVER | sed -e 's/\"//g'`
    DB2INST_HOME=`idlarg 8 $RIMINFO`
    DB2INST_HOME=`echo $DB2INST_HOME | sed -e 's/\"//g'`
    #-- If this is an Oracle installation which doesn't use SQL*Net,
    #-- the DBSERVER value will be null. idlarg return the string
    #-- 'null' in this case; set the variable to an empty string.
    [ "$DBSERVER" = "null" ] && DBSERVER=
    QUERY_RIM_INFO=0
  fi
fi

# If database info are available, provide a summary for each supported database

if [ "$QUERY_RIM_INFO" -eq 0 ]; then

  echo "      (I) RIM Object Configuration is:" 
  
  case $RIM_TYPE in
	  #--
	  *Sybase|SYBASE|sybase)
	    echo "          <> Database Vendor:    Sybase"
	    echo "          <> Database Server ID: $DBSERVER"
	    echo "          <> Database Home:      $DBHOME"
	    echo "          <> Database ID:        $DBID"
	    echo "          <> Database User ID:   $DBUSER"
	    ;;
	  #--
	  *Oracle|ORACLE|oracle)
	    echo "          <> Database Vendor:    Oracle"
	    echo "          <> Database Server:    $DBSERVER"
	    echo "          <> Database Home:      $DBHOME"
	    echo "          <> Database Alias:     $DBID"
	    echo "          <> Database User:      $DBUSER"
	    ;;
	  #--
	  *DB2|db2|Db2)
	    echo "          <> Database Vendor:    DB2"
	    echo "          <> Database Home:      $DBHOME"
	    echo "          <> Database Name:      $DBID"
	    echo "          <> Database User:      $DBUSER"
        echo "          <> DB2 Instance Home:  $DB2INST_HOME"	    
	    ;;
	  #--
	  *MS_SQL|ms_sql|MS_sql|MS_Sql|Ms_Sql)
	    if [ ! "$INTERP" = "w32-ix86" ]; then
	      echo "      (W) Warning. Invalid RDBMS for the Current Platform."
	    else
	      echo "          <> Database Vendor:    MS_SQL"
	      echo "          <> Database Server ID: $DBSERVER"
	      echo "          <> Database Home:      $DBHOME"
	      echo "          <> Database ID:        $DBID"
	      echo "          <> Database User ID:   $DBUSER"
	    fi
	    ;;
	  #--
	  *Informix|INFORMIX|informix)
	    echo "          <> Database Vendor:    Informix"
	    echo "          <> Database Server ID: $DBSERVER"
	    echo "          <> Database Home:      $DBHOME"
	    echo "          <> Database ID:        $DBID"
	    echo "          <> Database User ID:   $DBUSER"
	    ;;
	  #-- default...
	  *)
	    echo "      (W) Unknown/Unsupported RDBMS Platform."
	    ;;
  esac
fi

#-- get the sattus of the RIM trace
RIMTRACE=`wrimtrace $RIMONM`

case $RIMTRACE in
  *ERROR*)
	    echo "      (I) The RIM Host Traces only ERROR messages"
  ;;
  *INFORMATION*)
	    echo "      (I) The RIM Host Traces both ERROR and INFORMATION messages"
  ;;
  *)
	    echo "      (I) The RIM Host Trace is turned OFF"
  ;;
esac

#------------------------
##### Test the RIM Object
#------------------------

echo "==> Testing RIM Object ($RIMONM) Connectivity..."

echo "      (I) Attempting to Connect..." 

RIMTEST=`wrimtest -l $RIMONM << EOF
x
EOF`

case $RIMTEST in
  *Opened*)
  echo "      (I) RIM Object ($RIMONM) is Working Properly" 
  ;;
  *)
  echo "      (F) ITM0005E Error. Unable to Open a Valid RIM Session."
  itm_error_hint 5;
  echo "";
  exit 5;
  ;;
esac

#-------------------------------------
##### Get Data Collector Configuration
#-------------------------------------

echo "==> Retrieving Data Collector Configuration..."

DCCONFIG=`wdmconfig -G datacollector.* 2>/dev/null`

#-- default configuration values
datacollector_max_retry_time_default="6";
datacollector_sleep_time_default="1"
datacollector_delay_default="20";
datacollector_db_purge_time_default="0";
datacollector_db_purge_interval_default="30";

echo "$DCCONFIG" | (
#-- skip the two lines of the header
read r; read r;
while read a b c
do
  case $a in
    #-- Specifies the name of the RIM object that the data collection process will use to load
    #-- data to the database. The default is itm_rim_RIM host name.
    datacollector.rim_name)
      if [ $c = $RIMONM ]; then
        echo "      (I) RIM Object ($RIMONM) Matches" 
        echo "          the Data Collector Configuration" 
      else
        echo "      (F) ITM0006E Error. The RIM Object is Not Properly Configured."
        itm_error_hint 6;
        echo "";
        exit 6;
      fi
    ;;
    #-- Specifies the maximum number of times an XML data file must be processed before
    #-- being archived when an error occurs. The default is 6 times.
    datacollector.max_retry_time)
      if [ "-$c-" = "-$datacollector_max_retry_time_default-" ]; then
        datacollector_max_retry_time="$datacollector_max_retry_time_default (default)";
      else
        datacollector_max_retry_time="$c";
      fi
    ;;
    #-- Specifies the time interval (in minutes) between two consecutive requests of data
    #-- uploading generated by the data collector processor. The value can range from 1 to
    #-- 60 minutes. The default is 1 minute.
    datacollector.sleep_time)
      if [ "-$c-" = "-$datacollector_sleep_time_default-" ]; then
        datacollector_sleep_time="$datacollector_sleep_time_default (default)";
      else
        datacollector_sleep_time="$c";
      fi
    ;;
    #-- Specifies the time delay (in minutes, compared to the hour) after which the data
    #-- collector process uploads data from the endpoints. The value can range from 1 to 60
    #-- minutes. The default is 30 minutes.
    datacollector.delay)
      if [ "-$c-" = "-$datacollector_delay_default-" ]; then
        datacollector_delay="$datacollector_delay_default (default)";
      else
        datacollector_delay="$c";
      fi
    ;;
    #-- Specifies the time during the day for the data removal operation. 
    #-- The value can range from 0 (midnight) to 23. The default is 0 (midnight).
    datacollector.db_purge_time)
      if [ "-$c-" = "-$datacollector_db_purge_time_default-" ]; then
        datacollector_db_purge_time="$datacollector_db_purge_time_default (default)";
      else
        datacollector_db_purge_time="$c";
      fi
    ;;
    #-- Specifies the number of days the data is kept on the database: older data is
    #-- automatically removed from the database. The value can range from 10 to 60. The
    #-- default is 30 days.    
    datacollector.db_purge_interval)
      if [ "-$c-" = "-$datacollector_db_purge_interval_default-" ]; then
        datacollector_db_purge_interval="$datacollector_db_purge_interval_default (default)";
      else
        datacollector_db_purge_interval="$c";
      fi
    ;;
  esac
done

if [ -z "$datacollector_max_retry_time" ]; then
  $datacollector_max_retry_time="$datacollector_max_retry_time_default (default)";
fi
echo "      (I) The XML files will be processed $datacollector_max_retry_time"
echo "          times before being archived."

if [ -z "$datacollector_sleep_time" ]; then
  $datacollector_sleep_time="$datacollector_sleep_time_default (default)";
fi
echo "      (I) The time between two consecutive requests of"
echo "          data upload is $datacollector_sleep_time minutes." 

if [ -z "$datacollector_delay" ]; then
  $datacollector_delay="$datacollector_delay_default (default)";
fi
echo "      (I) Data will be uploaded $datacollector_delay minutes"
echo "          past the full hour." 

if [ -z "$datacollector_db_purge_time" ]; then
  $datacollector_db_purge_time="$datacollector_db_purge_time_default (default)";
fi
echo "      (I) Old data will be removed from the ITM database"
echo "          at $datacollector_db_purge_time o'clock."

if [ -z "$datacollector_db_purge_interval" ]; then
  $datacollector_db_purge_interval="$datacollector_db_purge_interval_default (default)";
fi
echo "      (I) The ITM database will not retain data older"
echo "          then $datacollector_db_purge_interval days." 

)

#-----------------------------------------
##### Get Middle Layer Trace Configuration
#-----------------------------------------

echo "==> Retrieving Middle Layer Trace Configuration..."

MLTCONFIG=`wdmconfig -G dmml.* 2>/dev/null`

#-- default configuration values
dmml_trace_level_default="1";
dmml_trace_size_default="500000";
  
echo "$MLTCONFIG" | (
#-- skip two lines the header
read r; read r;
while read a b c
do
  case $a in
    #-- Specifies the size of the profile distribution trace in bytes; 
    #-- default is 500000 bytes.
    dmml.trace_size)
      if [ "-$c-" = "-$dmml_trace_size_default-" ]; then
        dmml_trace_size="$dmml_trace_size_default (default)";
      else
        dmml_trace_size="$c";
      fi
    ;;
    #-- Specifies the level of the profile distribution trace from 
    #-- 0 (minimal) to 4 (verbose); the default is 1.
    dmml.trace_level)
      if [ "-$c-" = "-$dmml_trace_level_default-" ]; then
        dmml_trace_level="$dmml_trace_level_default (default)";
      else
        dmml_trace_level="$c";
      fi
    ;;
  esac
done

if [ -z "$dmml_trace_level" ]; then
  dmml_trace_level="$dmml_trace_level_default (default)";
fi
if [ -z "$dmml_trace_size" ]; then
  dmml_trace_size="$dmml_trace_level_default (default)";
fi

echo "      (I) The profile distribution trace is at level $dmml_trace_level"
echo "          and has a size of $dmml_trace_size bytes." 

)

#------------------------
##### Get EP Cache Status
#------------------------

echo "==> Retrieving the Status of the EP cache..."

EPCACHE=`wdmmngcache -l 2>/dev/null`

echo "$EPCACHE" | (
#-- skip the three lines of the header...
read r; read r; read r;
while read a b
do
  b_tmp=`echo $b | sed "s/ 	//g"`
  if [ -z "$b_tmp" ]; then
    echo "      (W) The EP Cache is Empty." 
  else
    echo "      (I) Cache status is: $b_tmp for Endpoint: $a" 
  fi
done
)

#-----------------------
##### Get Request Status
#-----------------------

echo "==> Retrieving Info about the Queued Requests..."

#-- get the queued requests
REQUESTS=`wdmcollect -q`;

REQINFO="<empty>";

REQINFO=`echo "$REQUESTS" | (
#-- skip the informational header
read r;
while read a
do
 #-- strip the main element tags from the XML stream
 if [ "-$a-" = "-<Requests>-" ]; then
   continue;
 elif [ "-$a-" = "-</Requests>-" ]; then
   break;
 else
   echo "$a";
 fi
done
)`

#-- extract only the attributes of the XML element <Request />
REQINFO=` echo "$REQINFO" | sed "s/<Request//g" | sed "s/\/>$//g" `

if [ -z "$REQINFO" ]; then
  echo "      (W) No Queued Requests Found!";
else
  #-- iterate over the extracted attributes and display them
  echo "$REQINFO" | (
  while read a b c d
  do
    echo "      (I) $b";
    echo "          $d";
  done
  )
fi

echo "==> Done."

#-----------------------
##### Analysis Completed
#-----------------------
display_footer;

