#!/bin/sh
###############################################################################
#
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#  File Information: %W%
#  Revision: %I%
#  Date: %G% %U%
#
###############################################################################

################################################################################
# Prepare an executable script for the execsql tool in a temporary directory
# To call: build_execsql_script $1 $2
#   $1 SQL script name
#   $2 database type (ITM, CDW, MART, MD)
################################################################################
build_execsql_script()
{

script_file="$1";
db_type="$2"

_script_extension="";
_script_file_with_extension="";

echo "      (I) Preparing script ($script_file) for ($db_type) database"

# Set the script extension based on the database type
if [ "$db_type" = "ITM" ]; then
  case "$ITM_DB_TYPE" in
    DB2|db2|Db2)
      _script_extension=".db2"
      ;;
    ORACLE|oracle|Oracle)
      _script_extension=".oracle"
      ;;
    MS_SQL|ms_sql|MS_Sql|Ms_Sql|Ms_SQL)
      _script_extension=".mssql"
      ;;
    INFORMIX|informix|Informix)
      _script_extension=".informix"
      ;;
    SYBASE|sybase|Sybase)
      _script_extension=".sybase"
      ;;
    *)
      echo "      (F) ITMIC0020E Unknown Database Type: cannot determine a valid script extension"
      echo ""
      exit 20
      ;;
  esac
else
  _script_extension=".db2";
fi

# replace the generic .sql extension with the one based on the database type
_script_file_with_extension=`echo $script_file | sed "s/.sql/$_script_extension/g" `

_tmp_script_file="$TMPDIR/tmp_$_script_file_with_extension";

# does the temporary script file already exist?
if [ -e $_tmp_script_file ]; then
  # yes, remove it...
  rm -f $_tmp_script_file;
fi

# create the executable script copying the content of the original script_file
cat "./sql/$script_file" > "$_tmp_script_file"

# check if the generated script has read permission for the user running the scipt
if [ ! -r "$_tmp_script_file" ]; then
  echo "      (F) ITMIC0021E Error trying to read the execution script"
  rm -f "$_tmp_script_file"
  exit 21
fi

echo "      (I) Executable script prepared"

return 0;
}

###############################################################################
# Executes an SQL script using the execsql tool to connect to the ITM_DB
# and dumps selected data to the standard output.
# To call:	run_execsql_script $1 $2 ($3);
#	$1 = SQL script name
#   $2 = source database type
#   $3 = target database type
###############################################################################
run_execsql_script() 
{

script_file="$1";
source_db_type="$2";
target_db_type="$3";

_source_db="";
_source_db_user="";
_source_db_pass="";
_target_db="";
_target_db_user="";
_target_db_pass="";

_tmp_execsql_out="$TMPDIR/tmp_execsql_out.log";

# prepare the executable script
build_execsql_script "$script_file" "$source_db_type"

# remove any extension before executing the script
_tmp_script_file=`echo $TMPDIR/tmp_$script_file | sed "s/\..*//g"`;

# determine the connect info according to the supplied database types
case "$source_db_type" in
  ITM)
    _source_db="$ITM_DB_ALIAS";
    _source_db_user="$ITM_DB_USER";
    _source_db_pass="$ITM_DB_PASS";
    ;;
  CDW)
    _source_db="$TWH_CDW_DB";
    _source_db_user="$TWH_CDW_DB_USER";
    _source_db_pass="$TWH_CDW_DB_PASS";
    ;;
  MART)
    _source_db="$TWH_DM_DB";
    _source_db_user="$TWH_DM_DB_USER";
    _source_db_pass="$TWH_DM_DB_PASS";
    ;;
  MD)
    _source_db="$TWH_CTRL_DB";
    _source_db_user="$TWH_CTRL_DB_USER";
    _source_db_pass="$TWH_CTRL_DB_PASS";
    ;;
  *)
    echo "      (F) ITMIC0020E Unknown Database Type: cannot create an executable script"
    echo ""
    exit 20
  ;;
esac

if [ "$target_db_type" != "" ]; then
  case "$target_db_type" in
    ITM)
      _target_db="$ITM_DB_ALIAS";
      _target_db_user="$ITM_DB_USER";
      _target_db_pass="$ITM_DB_PASS";
      ;;
    CDW)
      _target_db="$TWH_CDW_DB";
      _target_db_user="$TWH_CDW_DB_USER";
      _target_db_pass="$TWH_CDW_DB_PASS";
      ;;
    MART)
      _target_db="$TWH_DM_DB";
      _target_db_user="$TWH_DM_DB_USER";
      _target_db_pass="$TWH_DM_DB_PASS";
      ;;
    MD)
      _target_db="$TWH_CTRL_DB";
      _target_db_user="$TWH_CTRL_DB_USER";
      _target_db_pass="$TWH_CTRL_DB_PASS";
      ;;
    *)
      echo "      (F) ITMIC0020E Unknown Database Type: cannot create an executable script"
      echo ""
      exit 20
    ;;
  esac
fi

# execute the prepared script
if [ "$target_db_type" = "" ]; then
  echo "      (I) Executing SQL script ($script_file) on ($source_db_type) database ";
  blah=`$EXECSQL "$_tmp_script_file" "$_tmp_execsql_out" "$_source_db" "$_source_db_user" "$_source_db_pass" `
else
  echo "      (I) Executing SQL script ($script_file) from ($source_db_type) to ($target_db_type) database ";
  blah=`$EXECSQL "$_tmp_script_file" "$_tmp_execsql_out" "$_source_db" "$_source_db_user" "$_source_db_pass" "$_target_db" "$_target_db_user" "$_target_db_pass" `
fi

if [ $? -ne 0 ]; then
  echo "      (F) ITMIC0022E Errror executing the script ($script_file)"
  exit 22
else
  rm -rf "$_tmp_script_file".*;
fi

echo "      (I) Formatting Dumped Data "

# format the dumped data
cat $_tmp_execsql_out | grep -v "^\ *=" | grep -v "^\ \ 1\ *$" >> "./out/$REPORT_FILENAME"

# remove the temporary execsql log file
rm -rf $_tmp_execsql_out;

return 0;
}
