#!/bin/sh
###############################################################################
#
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#  File Information: %W%
#  Revision: %I%
#  Date: %G% %U%
#
###############################################################################

###############################################################################
# Set the program Non configurable variables required in all files using 
###############################################################################
gen_file_and_path=`echo $0 | sed 's/\\\\/\//g' `  # NT fix
PROGNAME=`basename "$gen_file_and_path"`
CONFIGFILE=`echo $PROGNAME | sed "s/\..*/.cfg/g"`
CURRENT_DATE=`date +"%b %d %Y %T"`;

###############################################################################
# Display Header Info
###############################################################################
display_header()
{
echo "";
echo "    ========================================================";
echo "    IBM Tivoli Monitoring - Tivoli Enterprise Data Warehouse";
echo "               Configuration and Status Snapshot            ";
echo "                        (c) IBM - Tivoli                    ";
echo "    ========================================================";
echo "";

return 0
}

###############################################################################
# Display Footer Info
###############################################################################
display_footer()
{
echo "";
echo "    ========================================================";
echo "    ================== Analysis Completed ==================";
echo "    ===  Look at the out directory for detailed reports. ===";
echo "    ========================================================";
echo "    ==== Here is a summary of the discovered components ====";
echo "    ========================================================";

return 0
}

###############################################################################
# Display Help
###############################################################################
display_help()
{
echo ""
echo "  Program:  $PROGNAME"
echo ""
echo "  Desc:     this script provides a snaphot of the current status"
echo "            of the ITM-TEDW environment, including dumps of the"
echo "            more meaningfull tables from both the TEDW and ITM"
echo "            databases."
echo ""
echo "  Usage:    $PROGNAME [ options... ]"
echo ""
echo "  Options:"
echo "            -h, --help       = Help Inforamtion"
echo "            -d, --debug      = Run with Debug turned on"
echo "            -r  --retcode    = Display return code messages"
echo ""
echo "  Default Config File:"
echo "            $CONFIGFILE"
echo ""
echo "  Message Levels:"
echo "            (I) - Informational"
echo "            (W) - Warning"
echo "            (F) - Fatal"
echo ""

return 0
}

###############################################################################
# Set the Debug Mode
###############################################################################
set_debug_mode()
{
echo "==> Setting Debug Mode"

if [ -n "$DEBUG" ]; then
   set -x
   echo "      (I) Debug Mode Enabled"
else
   echo "      (I) Debug Disabled"
fi

return 0;
}

###############################################################################
# Pulls in the generic shared routines
###############################################################################
include_genroutines()
{

echo "==> Including Generic Routines"
. ./lib/genroutines.sh

echo "      (I) Done Including Generic Routines"
return 0;
}

###############################################################################
# Pulls in the configuration parser routines
###############################################################################
include_confroutines()
{

echo "==> Including Configuration Parser Routines"
. ./lib/confroutines.sh

echo "      (I) Done Including Configuration Parser Routines"
return 0;
}

###############################################################################
# Pulls in the data dumper routines
###############################################################################
include_dumproutines()
{

echo "==> Including Data Dumper Routines";
. ./lib/dumproutines.sh;

echo "      (I) Done Including Data Dumper Routines";

return 0;
}

###############################################################################
###############################################################################
########################## Main - Script Entry Point ##########################
###############################################################################
###############################################################################
#
# parse the CLI
#
while [ $# -ne 0 ]; do
  # Now look for the command line option
  case $1 in
        # Help Info
        --help|--HELP|-Help|-help|-H|-h)
            display_help;
            exit 0
            ;;
        # Run in Debug
        --debug|--DEBUG|--Debug|-debug|-D|-d)
            DEBUG=defined
            set_debug_mode;
            shift
            continue
            ;;
        # Display the return code messages
        --retcode|--RETCODE|--Retcode|-R|-r)
            display_header;
            display_return_code_messages;
            exit 0
            ;;
        # Default
        *)
            echo "      (F) Unknown option ($1)"
            echo ""
            display_help;
            exit 104
            ;;
  esac
done
#
# display application header info
#
display_header;
#
echo "==> Analysis started at: $CURRENT_DATE"
#
# import functions from the lib directory
#
include_genroutines;
include_confroutines;
include_dumproutines;
#
# Set the debug mode according to the CLI
#
set_debug_mode;
#
# Read and validates configuration parameters from the config file
#
read_config_file "twhchk.cfg";
#
# Set Global Env Vars
#
set_program_vars;
#
# Prepare the analysis report
#
prepare_report;
#
###############################################################################
############################# Execute Data Dumps ##############################
###############################################################################
#
echo "==> Dumping Raw Data from the ITM Database"
put_info "ITM Endpoints Data";
run_execsql_script "itm_endpoints_data.sql" "ITM"
put_info "ITM Resource Model and Profiles Data";
run_execsql_script "itm_rmprofiles_data.sql" "ITM"
#
echo "==> Dumping Most Recent ITM Data";
put_info "Most Recent Data Loaded into the ITM Database";
run_execsql_script "itm_tail_data.sql" "ITM"
#
echo "==> Looking for AMX Exceptions on CDW";
put_info "AMX Exception Tables";
run_execsql_script "twh_amx_exceptions.sql" "CDW"
#
echo "==> Dumping Info on the Extraction History";
put_info "Extraction History";
run_execsql_script "twh_extract_control.sql" "CDW"
#
# Add here any other usefull sql script to be executed on
# the ITM, CDW, MD or MART database
# .....
#
###############################################################################
#
# Analysis completed: display footer info
#
display_footer;

echo "==> Done."

#
# Display the TEDW installation summary
#
tedw_inventory;
